/* $Id: ByteLimitedDocument.java,v 1.2 2007/10/24 09:10:39 nito Exp $
 * 
 * Copyright (c)ARGO 21, Corporation. 2005, 2006.  All rights reserved.
 * 
 * This file is part of Nautica Workflow.
 * 
 *  Nautica Workflow is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 * 
 *  Nautica Workflow is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 * 
 *  You should have received a copy of the GNU General Public License
 *  along with Nautica Workflow; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 *  
 */
package jp.co.argo21.nautica.commons.swing;

import javax.swing.text.*;

/**
 * バイト数限定入力用フィールドのための制御を行う。バイト数はSJISコードにて計算する。
 * <br>Javaは、日本語FEPを使用して入力を行うと、Java側が未確定の文字にもかかわらず、
 * キー入力のたびにいったん挿入してその数分削除を繰り返す仕様になっている。
 * これに対応するには、FEPの状態を知らねばならないが、現在容易なインタフェースはない。
 * よって、これは現在は<u>AttributeSetがnull以外</u>の場合、変換中文字列として取り扱い
 * それは処理の対象としないものとする。このため、潜在的な誤動作の可能性はあるが、
 * テストの範囲ではうまくいっている。テストには、Win NT + IME 2000を使用した。
 * <i>(2001/12/19 nito)</i></br>
 *
 * @author  Norihiro Itoh(ARGO 21 Corp.)
 * @version $Revision: 1.2 $
 * @since   Nautica Workflow 1.0
 */
public class ByteLimitedDocument extends PlainDocument
{
	/** シリアルバージョンID */
	private static final long serialVersionUID = 1L;

	/** バイト数 */
	private int limit;

	/**
	 * 入力制限用ドキュメントオブジェクトを生成する。
	 *
	 * @param limit 入力制限するバイト数
	 */
	public ByteLimitedDocument(int limit)
	{
		this.limit = limit;
	}

	/**
	 * 文字列挿入時の制御を行う。
	 *
	 * @param offset 挿入位置
	 * @param s      挿入文字列
	 * @param a      属性値
	 * @throws BadLocationException 指定された挿入の位置が、ドキュメント内の有効な位置ではない場合
	 */
	public void insertString(int offset, String s, AttributeSet a) throws BadLocationException
	{
		if (s == null) return;

		String currentString = getText(0, getLength());
		byte[] currentBytes = null;
		byte[] insertBytes  = null;
		try {
			currentBytes = currentString.getBytes("SJIS");
			insertBytes  = s.getBytes("SJIS");
		} catch (Exception ex) {}

		//日本語入力システムで変換中の値は制限をかけず、確定文字列のみを処理する。
		if (a == null) {
			if ((currentBytes.length + insertBytes.length) > limit) return;
		}

		super.insertString(offset, s, a);
	}
}
