/*
 * $Id: ColorChooser.java,v 1.1 2007/10/19 07:24:21 nito Exp $
 *
 * Copyright (c) 1999 Norihiro Itoh, All rights reserved.
 *
 * This source file is a part of Umlaut UML editor.
 * By using this file, you agree to the terms and conditions set
 * forth in the LICENSE file which can be found at the top level of
 * the Umlaut distribution.
 */
package jp.co.argo21.nautica.commons.swing;

import java.awt.BorderLayout;
import java.awt.Dimension;
import java.awt.FlowLayout;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;

import javax.swing.JButton;
import javax.swing.JColorChooser;
import javax.swing.JComponent;
import javax.swing.JDesktopPane;
import javax.swing.JFrame;
import javax.swing.JPanel;

/**
 * グリッド線の線幅の変更を支援する画面です。
 * 
 * @author 伊藤宣博
 * @version $Revision: 1.1 $, $Date: 2007/10/19 07:24:21 $
 * @since JDK1.2
 */
public final class ColorChooser extends JComponent
{
	/**
	 * 
	 */
	private static final long serialVersionUID = 1L;
	
	private JColorChooser view;
	private ColorReceiver receiver;
	
	/**
	 * グリッドマネージャのインスタンスを生成します。
	 */
	public ColorChooser()
	{
		BorderLayout layout = new BorderLayout();
		setLayout(layout);

		view = new JColorChooser();
		add(view, BorderLayout.CENTER);

		JButton set = new JButton(SwingResourceManager.getResource("ColorChooser.setButton"));
		set.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent e)
			{
				if (receiver != null) {
					receiver.setColor(view.getColor());
				}
			}			
		});
		set.setPreferredSize(new Dimension(100, 30));
		set.setSize(new Dimension(100, 30));

		JPanel buttonPanel = new JPanel(new FlowLayout(FlowLayout.RIGHT, 10, 10));
		buttonPanel.add(set);
		add(buttonPanel, BorderLayout.SOUTH);
	}
	
	public void setColorReceiver(ColorReceiver r)
	{
		if (r != null) {
			view.setColor(r.getColor());
			receiver = r;
			repaint();
		}
	}
	
	public static JFrame createFrame(ColorChooser cc)
	{
		JFrame frame = new JFrame(SwingResourceManager.getResource("ColorChooser.JFrame.title"));
		frame.setBounds(200, 100, 300, 400);
		frame.setContentPane(cc);
		return frame;
	}
	
	public static InternalFrame<ColorChooser> createInternalFrame(ColorChooser cc)
	{
		InternalFrame<ColorChooser> frame = new InternalFrame<ColorChooser>(
				SwingResourceManager.getResource("ColorChooser.JFrame.title"),
				true,
				true,
				false,
				false);
		frame.setLayer(JDesktopPane.PALETTE_LAYER);
		//frame.setBounds(200, 100, 300, 400);
		frame.setContentPane(cc);
		//frame.validate();
		frame.pack();
		return frame;
	}
}

